@@ -13,12 +13,12 @@ from confluent_kafka.schema_registry.avro import AvroSerializer, AvroDeserialize
 from confluent_kafka.serialization import StringSerializer, StringDeserializer, Serializer, Deserializer, \
     SerializationContext
 
-from ..entities import AlarmLocation, AlarmPriority, ChannelError, \
-    SimpleProducer, AlarmInstance, AlarmActivationUnion, SimpleAlarming, \
-    EPICSAlarming, NoteAlarming, DisabledOverride, FilteredOverride, LatchedOverride, MaskedOverride, \
+from ..entities import AlarmLocation, AlarmPriority, ChannelErrorActivation, NoActivation, \
+    Source, AlarmInstance, AlarmActivationUnion, Activation, \
+    EPICSActivation, NoteActivation, DisabledOverride, FilteredOverride, LatchedOverride, MaskedOverride, \
     OnDelayedOverride, OffDelayedOverride, ShelvedOverride, AlarmOverrideUnion, OverriddenAlarmType, AlarmOverrideKey, \
-    ShelvedReason, EPICSSEVR, EPICSSTAT, UnionEncoding, CALCProducer, EPICSProducer, AlarmClass, \
-    EffectiveRegistration, EffectiveActivation, EffectiveAlarm, IntermediateMonolog, AlarmState, AlarmOverrideSet, \
+    ShelvedReason, EPICSSEVR, EPICSSTAT, UnionEncoding, CALCSource, EPICSSource, AlarmClass, \
+    EffectiveRegistration, EffectiveNotification, EffectiveAlarm, IntermediateMonolog, AlarmState, AlarmOverrideSet, \
     ProcessorTransitions
 from ..references.avro import AvroDeserializerWithReferences, AvroSerializerWithReferences
 
@@ -110,17 +110,24 @@ class RegistryAvroSerde(Serde):
     """
         AVRO Serde which relies on Confluent Schema Registry.
     """
-    def __init__(self, schema_registry_client: SchemaRegistryClient, schema: Schema, union_encoding: UnionEncoding):
+    def __init__(self, schema_registry_client: SchemaRegistryClient, schema: Schema, union_encoding: UnionEncoding,
+                 avro_conf: Dict = None):
         """
             Creates a new RegistryAvroSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
             :param schema: The Schema
             :param union_encoding: The union encoding to use
+            :param avro_conf: configuration for avro serde
         """
+        if avro_conf is None:
+            avro_conf = {'auto.register.schemas': False,
+                         'use.latest.version': True}
+
         self._schema_registry_client = schema_registry_client
         self._schema = schema
         self._union_encoding = union_encoding
+        self.avro_conf = avro_conf
 
     @abstractmethod
     def from_dict(self, data: Dict) -> Any:
@@ -197,7 +204,8 @@ class RegistryAvroSerde(Serde):
     def serializer(self) -> Serializer:
         return AvroSerializer(self._schema_registry_client,
                               self._schema.schema_str,
-                              self._to_dict_with_ctx)
+                              self._to_dict_with_ctx,
+                              self.avro_conf)
 
     def deserializer(self) -> Deserializer:
         return AvroDeserializer(self._schema_registry_client,
@@ -211,7 +219,7 @@ class RegistryAvroWithReferencesSerde(RegistryAvroSerde):
         AVRO Registry Serde with Schema References support.
     """
     def __init__(self, schema_registry_client: SchemaRegistryClient, schema: Schema, union_encoding: UnionEncoding,
-                 references: List[SchemaReference], named_schemas: Dict[str, Any]):
+                 references: List[SchemaReference], named_schemas: Dict[str, Any], avro_conf: Dict = None):
         """
             Create a new RegistryAvroWithReferencesSerde.
 
@@ -220,11 +228,12 @@ class RegistryAvroWithReferencesSerde(RegistryAvroSerde):
             :param union_encoding: The union encoding to use
             :param references: List of SchemaReference
             :param named_schemas: Dict of named schemas
+            :param avro_conf: configuration for avro serde
         """
         self._references = references
         self._named_schemas = named_schemas
 
-        super().__init__(schema_registry_client, schema, union_encoding)
+        super().__init__(schema_registry_client, schema, union_encoding, avro_conf)
 
     @abstractmethod
     def from_dict(self, data):
@@ -254,7 +263,8 @@ class RegistryAvroWithReferencesSerde(RegistryAvroSerde):
         return AvroSerializerWithReferences(schema_registry_client=self._schema_registry_client,
                                             schema=self.get_schema(),
                                             to_dict=self._to_dict_with_ctx,
-                                            named_schemas=self.named_schemas())
+                                            named_schemas=self.named_schemas(),
+                                            conf=self.avro_conf)
 
     def deserializer(self):
         return AvroDeserializerWithReferences(self._schema_registry_client,
@@ -264,34 +274,24 @@ class RegistryAvroWithReferencesSerde(RegistryAvroSerde):
                                               self.named_schemas())
 
 
-class ClassSerde(RegistryAvroWithReferencesSerde):
+class ClassSerde(RegistryAvroSerde):
     """
         Provides AlarmClass serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient):
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None):
         """
-            Create a new LocationSerde.
+            Create a new ClassSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
-        priority_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/AlarmPriority.avsc")
-        priority_schema_str = priority_bytes.decode('utf-8')
-
-        named_schemas = {}
-
-        ref_dict = json.loads(priority_schema_str)
-        fastavro.parse_schema(ref_dict, named_schemas=named_schemas)
-
-        priority_schema_ref = SchemaReference("org.jlab.jaws.entity.AlarmPriority", "alarm-priority", 1)
-        references = [priority_schema_ref]
-
         schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/AlarmClass.avsc")
         schema_str = schema_bytes.decode('utf-8')
 
-        schema = Schema(schema_str, "AVRO", references)
+        schema = Schema(schema_str, "AVRO", [])
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, avro_conf)
 
     def to_dict(self, data: AlarmClass) -> Dict[str, str]:
         """
@@ -307,7 +307,7 @@ class ClassSerde(RegistryAvroWithReferencesSerde):
             "rationale": data.rationale,
             "correctiveaction": data.corrective_action,
             "pointofcontactusername": data.point_of_contact_username,
-            "latching": data.latching,
+            "latchable": data.latchable,
             "filterable": data.filterable,
             "ondelayseconds": data.on_delay_seconds,
             "offdelayseconds": data.off_delay_seconds
@@ -327,7 +327,7 @@ class ClassSerde(RegistryAvroWithReferencesSerde):
                           data.get('rationale'),
                           data.get('correctiveaction'),
                           data.get('pointofcontactusername'),
-                          data.get('latching'),
+                          data.get('latchable'),
                           data.get('filterable'),
                           data.get('ondelayseconds'),
                           data.get('offdelayseconds'))
@@ -338,18 +338,19 @@ class LocationSerde(RegistryAvroSerde):
         Provides AlarmLocation serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient):
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None):
         """
             Create a new LocationSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
         schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/AlarmLocation.avsc")
         schema_str = schema_bytes.decode('utf-8')
 
         schema = Schema(schema_str, "AVRO", [])
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, avro_conf)
 
     def to_dict(self, data: AlarmLocation) -> Dict[str, str]:
         """
@@ -378,19 +379,20 @@ class ActivationSerde(RegistryAvroSerde):
     """
 
     def __init__(self, schema_registry_client: SchemaRegistryClient,
-                 union_encoding: UnionEncoding = UnionEncoding.TUPLE):
+                 union_encoding: UnionEncoding = UnionEncoding.TUPLE, avro_conf: Dict = None):
         """
             Create a new ActivationSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
             :param union_encoding: The union encoding to use
+            :param avro_conf: configuration for avro serde
         """
         schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/AlarmActivationUnion.avsc")
         schema_str = schema_bytes.decode('utf-8')
 
         schema = Schema(schema_str, "AVRO", [])
 
-        super().__init__(schema_registry_client, schema, union_encoding)
+        super().__init__(schema_registry_client, schema, union_encoding, avro_conf)
 
     def to_dict(self, data: AlarmActivationUnion) -> Dict[str, Union[Tuple[str, Dict[str, str]],
                                                                      Dict[str, str],
@@ -398,32 +400,35 @@ class ActivationSerde(RegistryAvroSerde):
         """
             Converts an AlarmActivationUnion to a dict.
 
-            Note: The returned dict if not None is always keyed with "msg" and the value is either
+            Note: The returned dict if not None always contains a single field named "union", which is either
             a (1) Tuple, (2) Dict, or (3) Dict with one key which is name of union entity and valued with Dict.  This
             is determined by union_encoding.
 
             :param data: The AlarmActivationUnion
             :return: A dict
         """
-        if isinstance(data.msg, SimpleAlarming):
-            uniontype = "org.jlab.jaws.entity.SimpleAlarming"
+        if isinstance(data.union, Activation):
+            uniontype = "org.jlab.jaws.entity.Activation"
+            uniondict = {}
+        elif isinstance(data.union, EPICSActivation):
+            uniontype = "org.jlab.jaws.entity.EPICSActivation"
+            uniondict = {"sevr": data.union.sevr.name, "stat": data.union.stat.name}
+        elif isinstance(data.union, NoteActivation):
+            uniontype = "org.jlab.jaws.entity.NoteActivation"
+            uniondict = {"note": data.union.note}
+        elif isinstance(data.union, ChannelErrorActivation):
+            uniontype = "org.jlab.jaws.entity.ChannelErrorActivation"
+            uniondict = {"error": data.union.error}
+        elif isinstance(data.union, NoActivation):
+            uniontype = "org.jlab.jaws.entity.NoActivation"
             uniondict = {}
-        elif isinstance(data.msg, EPICSAlarming):
-            uniontype = "org.jlab.jaws.entity.EPICSAlarming"
-            uniondict = {"sevr": data.msg.sevr.name, "stat": data.msg.stat.name}
-        elif isinstance(data.msg, NoteAlarming):
-            uniontype = "org.jlab.jaws.entity.NoteAlarming"
-            uniondict = {"note": data.msg.note}
-        elif isinstance(data.msg, ChannelError):
-            uniontype = "org.jlab.jaws.entity.ChannelError"
-            uniondict = {"error": data.msg.error}
         else:
-            raise Exception(f"Unknown alarming union type: {data.msg}")
+            raise Exception(f"Unknown alarming union type: {data.union}")
 
         union = self._to_union(uniontype, uniondict)
 
         return {
-            "msg": union
+            "union": union
         }
 
     def from_dict(self, data: Dict[str, Union[Tuple[str, Dict[str, str]],
@@ -436,19 +441,21 @@ class ActivationSerde(RegistryAvroSerde):
             :param data: The dict
             :return: The AlarmActivationUnion
         """
-        unionobj = data['msg']
+        unionobj = data['union']
 
         uniontype, uniondict = self._from_union(unionobj)
 
-        if uniontype == "org.jlab.jaws.entity.NoteAlarming":
-            obj = NoteAlarming(uniondict['note'])
-        elif uniontype == "org.jlab.jaws.entity.EPICSAlarming":
-            obj = EPICSAlarming(_unwrap_enum(uniondict['sevr'], EPICSSEVR),
+        if uniontype == "org.jlab.jaws.entity.NoteActivation":
+            obj = NoteActivation(uniondict['note'])
+        elif uniontype == "org.jlab.jaws.entity.EPICSActivation":
+            obj = EPICSActivation(_unwrap_enum(uniondict['sevr'], EPICSSEVR),
                                 _unwrap_enum(uniondict['stat'], EPICSSTAT))
-        elif uniontype == "org.jlab.jaws.entity.ChannelError":
-            obj = ChannelError(uniondict['error'])
+        elif uniontype == "org.jlab.jaws.entity.ChannelErrorActivation":
+            obj = ChannelErrorActivation(uniondict['error'])
+        elif uniontype == "org.jlab.jaws.entity.NoActivation":
+            obj = NoActivation()
         else:
-            obj = SimpleAlarming()
+            obj = Activation()
 
         return AlarmActivationUnion(obj)
 
@@ -459,19 +466,20 @@ class InstanceSerde(RegistryAvroSerde):
     """
 
     def __init__(self, schema_registry_client: SchemaRegistryClient,
-                 union_encoding: UnionEncoding = UnionEncoding.TUPLE):
+                 union_encoding: UnionEncoding = UnionEncoding.TUPLE, avro_conf: Dict = None):
         """
             Create a new InstanceSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
             :param union_encoding: The union encoding to use
+            :param avro_conf: configuration for avro serde
         """
         schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/AlarmInstance.avsc")
         schema_str = schema_bytes.decode('utf-8')
 
         schema = Schema(schema_str, "AVRO", [])
 
-        super().__init__(schema_registry_client, schema, union_encoding)
+        super().__init__(schema_registry_client, schema, union_encoding, avro_conf)
 
     def to_dict(self, data: AlarmInstance) -> Dict[str, Union[str, Dict[str, Any]]]:
         """
@@ -480,23 +488,23 @@ class InstanceSerde(RegistryAvroSerde):
             :param data: The AlarmInstance
             :return: A dict
         """
-        if isinstance(data.producer, SimpleProducer):
-            uniontype = "org.jlab.jaws.entity.SimpleProducer"
+        if isinstance(data.source, Source):
+            uniontype = "org.jlab.jaws.entity.Source"
             uniondict = {}
-        elif isinstance(data.producer, EPICSProducer):
-            uniontype = "org.jlab.jaws.entity.EPICSProducer"
-            uniondict = {"pv": data.producer.pv}
-        elif isinstance(data.producer, CALCProducer):
-            uniontype = "org.jlab.jaws.entity.CALCProducer"
-            uniondict = {"expression": data.producer.expression}
+        elif isinstance(data.source, EPICSSource):
+            uniontype = "org.jlab.jaws.entity.EPICSSource"
+            uniondict = {"pv": data.source.pv}
+        elif isinstance(data.source, CALCSource):
+            uniontype = "org.jlab.jaws.entity.CALCSource"
+            uniondict = {"expression": data.source.expression}
         else:
-            raise Exception(f"Unknown instance producer union type: {data.producer}")
+            raise Exception(f"Unknown instance source union type: {data.source}")
 
-        union = self._to_union(uniontype, uniondict)
+        source = self._to_union(uniontype, uniondict)
 
         return {
-            "class": data.alarm_class,
-            "producer": union,
+            "alarmclass": data.alarm_class,
+            "source": source,
             "location": data.location,
             "maskedby": data.masked_by,
             "screencommand": data.screen_command
@@ -511,19 +519,19 @@ class InstanceSerde(RegistryAvroSerde):
             :param data: The dict
             :return: The AlarmInstance
         """
-        unionobj = data['producer']
+        unionobj = data['source']
 
         uniontype, uniondict = self._from_union(unionobj)
 
-        if uniontype == "org.jlab.jaws.entity.CalcProducer":
-            producer = CALCProducer(uniondict['expression'])
-        elif uniontype == "org.jlab.jaws.entity.EPICSProducer":
-            producer = EPICSProducer(uniondict['pv'])
+        if uniontype == "org.jlab.jaws.entity.CALCSource":
+            source = CALCSource(uniondict['expression'])
+        elif uniontype == "org.jlab.jaws.entity.EPICSSource":
+            source = EPICSSource(uniondict['pv'])
         else:
-            producer = SimpleProducer()
+            source = Source()
 
-        return AlarmInstance(data.get('class'),
-                             producer,
+        return AlarmInstance(data.get('alarmclass'),
+                             source,
                              data.get('location'),
                              data.get('maskedby'),
                              data.get('screencommand'))
@@ -534,11 +542,12 @@ class OverrideSetSerde(RegistryAvroWithReferencesSerde):
         Provides OverrideSet serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient) -> None:
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None) -> None:
         """
             Create a new OverrideSetSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
 
         disabled_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/DisabledOverride.avsc")
@@ -600,7 +609,8 @@ class OverrideSetSerde(RegistryAvroWithReferencesSerde):
 
         schema = Schema(schema_str, "AVRO", references)
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas,
+                         avro_conf)
 
     def to_dict(self, data: AlarmOverrideSet) -> Dict[str, Any]:
         """
@@ -653,11 +663,12 @@ class EffectiveRegistrationSerde(RegistryAvroWithReferencesSerde):
         Provides EffectiveRegistration serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient) -> None:
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None) -> None:
         """
             Create a new EffectiveRegistrationSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
         self._class_serde = ClassSerde(schema_registry_client)
         self._instance_serde = InstanceSerde(schema_registry_client)
@@ -674,7 +685,7 @@ class EffectiveRegistrationSerde(RegistryAvroWithReferencesSerde):
         instance_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/AlarmInstance.avsc")
         instance_schema_str = instance_bytes.decode('utf-8')
 
-        named_schemas = self._class_serde.named_schemas()
+        named_schemas = {}
 
         ref_dict = json.loads(classes_schema_str)
         fastavro.parse_schema(ref_dict, named_schemas=named_schemas)
@@ -686,7 +697,8 @@ class EffectiveRegistrationSerde(RegistryAvroWithReferencesSerde):
 
         schema = Schema(schema_str, "AVRO", references)
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas,
+                         avro_conf)
 
     def to_dict(self, data: EffectiveRegistration) -> Dict[str, Any]:
         """
@@ -713,16 +725,17 @@ class EffectiveRegistrationSerde(RegistryAvroWithReferencesSerde):
             if data.get('instance') is not None else None)
 
 
-class EffectiveActivationSerde(RegistryAvroWithReferencesSerde):
+class EffectiveNotificationSerde(RegistryAvroWithReferencesSerde):
     """
-        Provides EffectiveActivation serde utilities
+        Provides EffectiveNotification serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient) -> None:
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None) -> None:
         """
-            Create a new EffectiveActivationSerde.
+            Create a new EffectiveNotificationSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
         self._activation_serde = ActivationSerde(schema_registry_client)
         self._override_serde = OverrideSetSerde(schema_registry_client)
@@ -753,36 +766,37 @@ class EffectiveActivationSerde(RegistryAvroWithReferencesSerde):
         ref_dict = json.loads(state_schema_str)
         fastavro.parse_schema(ref_dict, named_schemas=named_schemas)
 
-        schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveActivation.avsc")
+        schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveNotification.avsc")
         schema_str = schema_bytes.decode('utf-8')
 
         schema = Schema(schema_str, "AVRO", references)
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas,
+                         avro_conf)
 
-    def to_dict(self, data: EffectiveActivation) -> Dict[str, Any]:
+    def to_dict(self, data: EffectiveNotification) -> Dict[str, Any]:
         """
-            Converts EffectiveActivation to a dict.
+            Converts EffectiveNotification to a dict.
 
-            :param data: The EffectiveActivation
+            :param data: The EffectiveNotification
             :return: A dict
         """
         return {
-            "actual": self._activation_serde.to_dict(data.actual) if data.actual is not None else None,
+            "activation": self._activation_serde.to_dict(data.activatio) if data.activation is not None else None,
             "overrides": self._override_serde.to_dict(data.overrides),
             "state": data.state.name
         }
 
-    def from_dict(self, data: Dict[str, Any]) -> EffectiveActivation:
+    def from_dict(self, data: Dict[str, Any]) -> EffectiveNotification:
         """
-            Converts a dict to EffectiveActivation.
+            Converts a dict to EffectiveNotification.
 
             :param data: The dict
-            :return: The EffectiveActivation
+            :return: The EffectiveNotification
         """
-        return EffectiveActivation(
-            self._activation_serde.from_dict(data['actual'][1])
-            if data.get('actual') is not None else None,
+        return EffectiveNotification(
+            self._activation_serde.from_dict(data['activation'][1])
+            if data.get('activation') is not None else None,
             self._override_serde.from_dict(data['overrides']),
             _unwrap_enum(data['state'], AlarmState))
 
@@ -792,35 +806,36 @@ class EffectiveAlarmSerde(RegistryAvroWithReferencesSerde):
         Provides EffectiveAlarm serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient) -> None:
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None) -> None:
         """
             Create a new EffectiveAlarmSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
         self._effective_registration_serde = EffectiveRegistrationSerde(schema_registry_client)
-        self._effective_activation_serde = EffectiveActivationSerde(schema_registry_client)
+        self._effective_notification_serde = EffectiveNotificationSerde(schema_registry_client)
 
         registration_schema_ref = SchemaReference("org.jlab.jaws.entity.EffectiveRegistration",
                                                   "effective-registrations-value", 1)
-        activation_schema_ref = SchemaReference("org.jlab.jaws.entity.EffectiveActivation",
-                                                "effective-activations-value", 1)
+        notification_schema_ref = SchemaReference("org.jlab.jaws.entity.EffectiveNotification",
+                                                "effective-notifications-value", 1)
 
-        references = [registration_schema_ref, activation_schema_ref]
+        references = [registration_schema_ref, notification_schema_ref]
 
         registrations_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveRegistration.avsc")
         registrations_schema_str = registrations_bytes.decode('utf-8')
 
-        activation_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveActivation.avsc")
-        activation_schema_str = activation_bytes.decode('utf-8')
+        notification_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveNotification.avsc")
+        notification_schema_str = notification_bytes.decode('utf-8')
 
         named_schemas = self._effective_registration_serde.named_schemas()
-        named_schemas.update(self._effective_activation_serde.named_schemas())
+        named_schemas.update(self._effective_notification_serde.named_schemas())
 
         ref_dict = json.loads(registrations_schema_str)
         fastavro.parse_schema(ref_dict, named_schemas=named_schemas)
 
-        ref_dict = json.loads(activation_schema_str)
+        ref_dict = json.loads(notification_schema_str)
         fastavro.parse_schema(ref_dict, named_schemas=named_schemas)
 
         schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveAlarm.avsc")
@@ -828,7 +843,8 @@ class EffectiveAlarmSerde(RegistryAvroWithReferencesSerde):
 
         schema = Schema(schema_str, "AVRO", references)
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, references, named_schemas,
+                         avro_conf)
 
     def to_dict(self, data: EffectiveAlarm) -> Dict[str, Any]:
         """
@@ -839,7 +855,7 @@ class EffectiveAlarmSerde(RegistryAvroWithReferencesSerde):
         """
         return {
             "registration": self._effective_registration_serde.to_dict(data.registration),
-            "activation": self._effective_activation_serde.to_dict(data.activation)
+            "notification": self._effective_notification_serde.to_dict(data.notification)
         }
 
     def from_dict(self, data: Dict[str, Any]) -> EffectiveAlarm:
@@ -850,7 +866,7 @@ class EffectiveAlarmSerde(RegistryAvroWithReferencesSerde):
             :return: The EffectiveAlarm
         """
         return EffectiveAlarm(self._effective_registration_serde.from_dict(data['registration']),
-                              self._effective_activation_serde.from_dict(data['activation']))
+                              self._effective_notification_serde.from_dict(data['notification']))
 
 
 class OverrideKeySerde(RegistryAvroSerde):
@@ -858,18 +874,19 @@ class OverrideKeySerde(RegistryAvroSerde):
         Provides OverrideKey serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient) -> None:
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None) -> None:
         """
             Create a new OverrideKeySerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
         schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/AlarmOverrideKey.avsc")
         schema_str = schema_bytes.decode('utf-8')
 
         schema = Schema(schema_str, "AVRO", [])
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, avro_conf)
 
     def to_dict(self, data: AlarmOverrideKey) -> Dict[str, str]:
         """
@@ -899,12 +916,13 @@ class OverrideSerde(RegistryAvroWithReferencesSerde):
     """
 
     def __init__(self, schema_registry_client: SchemaRegistryClient,
-                 union_encoding: UnionEncoding = UnionEncoding.TUPLE):
+                 union_encoding: UnionEncoding = UnionEncoding.TUPLE, avro_conf: Dict = None):
         """
             Create a new OverrideSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
             :param union_encoding: The union encoding to use
+            :param avro_conf: configuration for avro serde
         """
 
         self._union_encoding = union_encoding
@@ -968,7 +986,7 @@ class OverrideSerde(RegistryAvroWithReferencesSerde):
 
         schema = Schema(schema_str, "AVRO", references)
 
-        super().__init__(schema_registry_client, schema, union_encoding, references, named_schemas)
+        super().__init__(schema_registry_client, schema, union_encoding, references, named_schemas, avro_conf)
 
     def to_dict(self, data: AlarmOverrideUnion) -> Dict[str, Any]:
         """
@@ -977,37 +995,37 @@ class OverrideSerde(RegistryAvroWithReferencesSerde):
             :param data: The AlarmOverrideUnion
             :return: A dict
         """
-        if isinstance(data.msg, DisabledOverride):
+        if isinstance(data.union, DisabledOverride):
             uniontype = "org.jlab.jaws.entity.DisabledOverride"
-            uniondict = {"comments": data.msg.comments}
-        elif isinstance(data.msg, FilteredOverride):
+            uniondict = {"comments": data.union.comments}
+        elif isinstance(data.union, FilteredOverride):
             uniontype = "org.jlab.jaws.entity.FilteredOverride"
-            uniondict = {"filtername": data.msg.filtername}
-        elif isinstance(data.msg, LatchedOverride):
+            uniondict = {"filtername": data.union.filtername}
+        elif isinstance(data.union, LatchedOverride):
             uniontype = "org.jlab.jaws.entity.LatchedOverride"
             uniondict = {}
-        elif isinstance(data.msg, MaskedOverride):
+        elif isinstance(data.union, MaskedOverride):
             uniontype = "org.jlab.jaws.entity.MaskedOverride"
             uniondict = {}
-        elif isinstance(data.msg, OnDelayedOverride):
+        elif isinstance(data.union, OnDelayedOverride):
             uniontype = "org.jlab.jaws.entity.OnDelayedOverride"
-            uniondict = {"expiration": data.msg.expiration}
-        elif isinstance(data.msg, OffDelayedOverride):
+            uniondict = {"expiration": data.union.expiration}
+        elif isinstance(data.union, OffDelayedOverride):
             uniontype = "org.jlab.jaws.entity.OffDelayedOverride"
-            uniondict = {"expiration": data.msg.expiration}
-        elif isinstance(data.msg, ShelvedOverride):
+            uniondict = {"expiration": data.union.expiration}
+        elif isinstance(data.union, ShelvedOverride):
             uniontype = "org.jlab.jaws.entity.ShelvedOverride"
-            uniondict = {"expiration": data.msg.expiration, "comments": data.msg.comments,
-                         "reason": data.msg.reason.name, "oneshot": data.msg.oneshot}
+            uniondict = {"expiration": data.union.expiration, "comments": data.union.comments,
+                         "reason": data.union.reason.name, "oneshot": data.union.oneshot}
         else:
-            print(f"Unknown alarming union type: {data.msg}")
+            print(f"Unknown alarming union type: {data.union}")
             uniontype = None
             uniondict = None
 
         union = self._to_union(uniontype, uniondict)
 
         return {
-            "msg": union
+            "union": union
         }
 
     def from_dict(self, data: Dict[str, Any]) -> AlarmOverrideUnion:
@@ -1022,7 +1040,7 @@ class OverrideSerde(RegistryAvroWithReferencesSerde):
             :param data: The dict
             :return: The AlarmOverrideUnion
         """
-        unionobj = data['msg']
+        unionobj = data['union']
 
         uniontype, uniondict = self._from_union(unionobj)
 
@@ -1042,7 +1060,7 @@ class OverrideSerde(RegistryAvroWithReferencesSerde):
             obj = ShelvedOverride(uniondict['expiration'], uniondict['comments'],
                                   _unwrap_enum(uniondict['reason'], ShelvedReason), uniondict['oneshot'])
         else:
-            print(f"Unknown alarming type: {data['msg']}")
+            print(f"Unknown alarming type: {data['union']}")
             obj = None
 
         return AlarmOverrideUnion(obj)
@@ -1053,18 +1071,19 @@ class ProcessorTransitionsSerde(RegistryAvroSerde):
         Provides ProcessorTransitions serde utilities
     """
 
-    def __init__(self, schema_registry_client: SchemaRegistryClient):
+    def __init__(self, schema_registry_client: SchemaRegistryClient, avro_conf: Dict = None):
         """
             Create a new ProcessorTransitionSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
+            :param avro_conf: configuration for avro serde
         """
         schema_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/ProcessorTransition.avsc")
         schema_str = schema_bytes.decode('utf-8')
 
         schema = Schema(schema_str, "AVRO", [])
 
-        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE)
+        super().__init__(schema_registry_client, schema, UnionEncoding.DICT_WITH_TYPE, avro_conf)
 
     def to_dict(self, data: ProcessorTransitions) -> Dict[str, bool]:
         """
@@ -1107,22 +1126,23 @@ class IntermediateMonologSerde(RegistryAvroWithReferencesSerde):
     """
 
     def __init__(self, schema_registry_client: SchemaRegistryClient,
-                 union_encoding: UnionEncoding = UnionEncoding.DICT_WITH_TYPE):
+                 union_encoding: UnionEncoding = UnionEncoding.DICT_WITH_TYPE, avro_conf: Dict = None):
         """
             Create a new IntermediateMonologSerde.
 
             :param schema_registry_client: The SchemaRegistryClient
             :param union_encoding: The union encoding to use
+            :param avro_conf: configuration for avro serde
         """
         self._union_encoding = union_encoding
         self._effective_registration_serde = EffectiveRegistrationSerde(schema_registry_client)
-        self._effective_activation_serde = EffectiveActivationSerde(schema_registry_client)
+        self._effective_notification_serde = EffectiveNotificationSerde(schema_registry_client)
         self._processor_transition_serde = ProcessorTransitionsSerde(schema_registry_client)
 
         registration_schema_ref = SchemaReference("org.jlab.jaws.entity.EffectiveRegistration",
                                                   "effective-registrations-value", 1)
-        activation_schema_ref = SchemaReference("org.jlab.jaws.entity.EffectiveActivation",
-                                                "effective-activations-value", 1)
+        activation_schema_ref = SchemaReference("org.jlab.jaws.entity.EffectiveNotification",
+                                                "effective-notifications-value", 1)
         transitions_schema_ref = SchemaReference("org.jlab.jaws.entity.ProcessorTransitions",
                                                  "processor-transitions", 1)
 
@@ -1131,19 +1151,19 @@ class IntermediateMonologSerde(RegistryAvroWithReferencesSerde):
         registrations_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveRegistration.avsc")
         registrations_schema_str = registrations_bytes.decode('utf-8')
 
-        activation_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveActivation.avsc")
-        activation_schema_str = activation_bytes.decode('utf-8')
+        notification_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/EffectiveNotification.avsc")
+        notification_schema_str = notification_bytes.decode('utf-8')
 
         transitions_bytes = pkgutil.get_data("jaws_libp", "avro/schemas/ProcessorTransitions.avsc")
         transitions_schema_str = transitions_bytes.decode('utf-8')
 
         named_schemas = self._effective_registration_serde.named_schemas()
-        named_schemas.update(self._effective_activation_serde.named_schemas())
+        named_schemas.update(self._effective_notification_serde.named_schemas())
 
         ref_dict = json.loads(registrations_schema_str)
         fastavro.parse_schema(ref_dict, named_schemas=named_schemas)
 
-        ref_dict = json.loads(activation_schema_str)
+        ref_dict = json.loads(notification_schema_str)
         fastavro.parse_schema(ref_dict, named_schemas=named_schemas)
 
         ref_dict = json.loads(transitions_schema_str)
@@ -1154,7 +1174,7 @@ class IntermediateMonologSerde(RegistryAvroWithReferencesSerde):
 
         schema = Schema(schema_str, "AVRO", references)
 
-        super().__init__(schema_registry_client, schema, union_encoding, references, named_schemas)
+        super().__init__(schema_registry_client, schema, union_encoding, references, named_schemas, avro_conf)
 
     def to_dict(self, data: IntermediateMonolog) -> Dict[str, Any]:
         """
@@ -1165,7 +1185,7 @@ class IntermediateMonologSerde(RegistryAvroWithReferencesSerde):
         """
         return {
             "registration": self._effective_registration_serde.to_dict(data.registration),
-            "activation": self._effective_activation_serde.to_dict(data.activation),
+            "notification": self._effective_notification_serde.to_dict(data.notification),
             "transitions": self._processor_transition_serde.to_dict(data.transitions)
         }
 
@@ -1177,5 +1197,5 @@ class IntermediateMonologSerde(RegistryAvroWithReferencesSerde):
             :return: The IntermediateMonolog
         """
         return IntermediateMonolog(self._effective_registration_serde.from_dict(data['registration']),
-                                   self._effective_activation_serde.from_dict(data['activation']),
+                                   self._effective_notification_serde.from_dict(data['notification']),
                                    self._processor_transition_serde.from_dict(data['transitions']))
