@@ -6,17 +6,19 @@ import os
 import signal
 import socket
 import time
-from typing import Any, List, Callable, Tuple
+
+from typing import Any, List, Tuple, Dict
+
+import requests
 
 from confluent_kafka import Message, SerializingProducer, KafkaError
 from confluent_kafka.schema_registry import SchemaRegistryClient
 from psutil import Process
-from tabulate import tabulate
 
 from .avro.serde import LocationSerde, OverrideKeySerde, OverrideSerde, EffectiveRegistrationSerde, \
-    StringSerde, Serde, EffectiveAlarmSerde, EffectiveActivationSerde, ClassSerde, ActivationSerde, InstanceSerde
+    StringSerde, Serde, EffectiveAlarmSerde, EffectiveNotificationSerde, ClassSerde, ActivationSerde, InstanceSerde
 from .entities import UnionEncoding
-from .eventsource import EventSourceListener, CachedTable
+from .eventsource import EventSourceListener, EventSourceTable
 
 logger = logging.getLogger(__name__)
 
@@ -44,25 +46,7 @@ def get_registry_client() -> SchemaRegistryClient:
     return SchemaRegistryClient(sr_conf)
 
 
-class _MonitorListener(EventSourceListener):
-    """
-        Internal listener implementation for the JAWSConsumer.
-    """
-
-    def on_highwater_timeout(self) -> None:
-        """
-            Default callback for highwater timeout.
-        """
-
-    def on_batch(self, msgs: List[Message]) -> None:
-        for msg in msgs:
-            print("%s=%s", msg.key(), msg.value())
-
-    def on_highwater(self) -> None:
-        pass
-
-
-class JAWSConsumer(CachedTable):
+class JAWSConsumer(EventSourceTable):
     """
         This class consumes messages from JAWS.
 
@@ -72,64 +56,73 @@ class JAWSConsumer(CachedTable):
         This consumer also knows how to export records into a file using the JAWS expected file format.
     """
 
-    def __init__(self, topic: str, client_name: str, key_serde: Serde, value_serde: Serde):
+    def __init__(self, config):
         """
             Create a new JAWSConsumer with the provided attributes.
 
-        :param topic: The Kafka topic name
-        :param client_name: The name of the client application
-        :param key_serde: The appropriate Kafka message key Serde for the given topic
-        :param value_serde: The appropriate Kafka message value Serde for the given topic
-        """
-        self._topic = topic
-        self._client_name = client_name
-        self._key_serde = key_serde
-        self._value_serde = value_serde
+         Note:
+             The configuration options include all those for EventSourceTable and DeserializingConsumer plus:
 
+            +-------------------------+---------------------+-----------------------------------------------------+
+            | Property Name           | Type                | Description                                         |
+            +=========================+=====================+=====================================================+
+            | ``client.name``         | str                 | Name of client app                                  |
+            +-------------------------+---------------------+-----------------------------------------------------+
+            |                         |                     | Key Serde                                           |
+            | ``key.serde``           | Serde               |                                                     |
+            |                         |                     |                                                     |
+            +-------------------------+---------------------+-----------------------------------------------------+
+            |                         |                     | Value Serde                                         |
+            | ``value.serde``         | Serde               |                                                     |
+            |                         |                     |                                                     |
+            +-------------------------+---------------------+-----------------------------------------------------+
+
+            :param config: The Consumer config
+        """
         set_log_level_from_env()
 
         signal.signal(signal.SIGINT, self.__signal_handler)
 
         ts = time.time()
-
+        config['client.name'] = config['client.name'] if config['client.name'] is not None else 'JAWSConsumer'
+        self._key_serde = config['key.serde']
+        self._value_serde = config['value.serde']
         bootstrap_servers = os.environ.get('BOOTSTRAP_SERVERS', 'localhost:9092')
-        config = {'topic': topic,
-                  'bootstrap.servers': bootstrap_servers,
-                  'key.deserializer': key_serde.deserializer(),
-                  'value.deserializer': value_serde.deserializer(),
-                  'group.id': client_name + str(ts)}
+        defaults = {'bootstrap.servers': bootstrap_servers,
+                    'group.id': config['client.name'] + str(ts),
+                    'key.deserializer': self._key_serde.deserializer(),
+                    'value.deserializer': self._value_serde.deserializer(),
+                    'enable.auto.commit': False,
+                    'auto.offset.reset': 'earliest'}
 
-        super().__init__(config)
+        conf_copy = defaults.copy()
+        conf_copy.update(config)
 
-    def print_table(self, nometa: bool = False,
-                    filter_if: Callable[[Any, Any], bool] = lambda key, value: True) -> None:
+        # Remove all JAWSConsumer specific configs as Consumer will complain if unrecognized configs found
+        del conf_copy['client.name']
+        del conf_copy['key.serde']
+        del conf_copy['value.serde']
+
+        super().__init__(conf_copy)
+
+        caching_enabled = self._config.get('compacted.cache') \
+            if self._config.get('compacted.cache') is not None else True
+        if caching_enabled:
+            self._cache_listener = _CacheListener()
+            self.add_listener(self._cache_listener)
+
+    def await_highwater_get(self) -> Dict[Any, Message]:
         """
-            Prints the compacted cache of records as a table to standard output.
+            Block the calling thread and wait for topic highwater to be reached, then return cache of compacted
+            messages.
 
-            Note: Blocks until the highwater mark has been reached.
+            See: The 'highwater.timeout' option passed to the config Dict in constructor
 
-            :param nometa: If True, exclude timestamp, producer app name, host, and username from table
-            :param filter_if: Callback applied to each Message to indicate if Message should be included
-            :raises: TimeoutException if unable to obtain initial list of records up to highwater before timeout
+            :return: The cache of compacted messages
+            :raises TimeoutException: If highwater is not reached before timeout
         """
-        head = self._get_table_headers()
-
-        records = self.await_highwater_get()
-
-        table = []
-
-        if not nometa:
-            head = ["Timestamp", "User", "Host", "Produced By"] + head
-
-        for record in records.values():
-            row = self.__filtered_row_with_header(record, filter_if, nometa)
-            if row is not None:
-                table.append(row)
-
-        # Truncate long cells
-        table = [[(c if len(str(c)) < 30 else str(c)[:27] + "...") for c in row] for row in table]
-
-        print(tabulate(table, head))
+        self.await_highwater()
+        return self._cache_listener.get_cache()
 
     def __to_line(self, key: Any, value: Any) -> str:
         """
@@ -164,112 +157,35 @@ class JAWSConsumer(CachedTable):
             if filter_if(key, value):
                 print(self.__to_line(key, value))
 
-    # pylint: disable=no-self-use
-    # check breaks inheritance
-    def _get_table_headers(self) -> List[str]:
-        """
-            Get the printed table headers.
-
-            :return: The list of table headers
-        """
-        return ["Key", "Value"]
-
-    # pylint: disable=no-self-use
-    # check breaks inheritance
-    def _get_table_row(self, msg: Message) -> List[str]:
-        """
-            Function to convert Message to table row (List of strings).
-
-            Note: This function assumes the Message.value() is never None as
-            this function should be called against a compacted Dict of Messages.
-
-            :param msg: The Message
-            :return: The table row (List of strings)
-        """
-        return [msg.key(), msg.value()]
-
-    def get_keys_then_done(self) -> List[Any]:
-        """
-            Convenience function to get the list of keys.  This function blocks until the highwater mark is reached.
-
-            WARNING: No other functions should be called on this JAWSConsumer afterwards as start() and stop() are
-            called.
-
-            :return: List of keys
-        """
-        self.start()
-        msgs = self.await_highwater_get()
-        self.stop()
-
-        return msgs.keys()
-
-    def consume_then_done(self, monitor: bool = False, nometa: bool = False, export: bool = False,
-                          filter_if: Callable[[Any, Any], bool] = lambda key, value: True) -> None:
-        """
-            Convenience function for taking exactly one action given a set of hints.  If more than one action is
-            indicated the first one in parameter order wins.  If Neither monitor nor export is indicated then
-            print_table is called.
-
-            WARNING: No other functions should be called on this JAWSConsumer afterwards as start() and stop() are
-            called.
-
-            :param monitor: If True print records as they arrive (uncompressed) indefinitely (kill with Ctrl-C)
-            :param nometa: If True do not include timestamp, producer app, host, and username in output
-            :param export: If True call export_records()
-            :param filter_if: Callback applied to each Message to indicate if Message should be included
-        """
-        if monitor:
-            self.add_listener(_MonitorListener())
-            self.start()
-        elif export:
-            self.start()
-            self.export_records(filter_if)
-            self.stop()
-        else:
-            self.start()
-            self.print_table(nometa, filter_if)
-            self.stop()
-
-    def __filtered_row_with_header(self, msg: Message, filter_if: Callable[[Any, Any], bool], nometa: bool):
-        timestamp = msg.timestamp()
-        headers = msg.headers()
-
-        row = self._get_table_row(msg)
-
-        if filter_if(msg.key(), msg.value()):
-            if not nometa:
-                row_header = self.__get_row_meta_header(headers, timestamp)
-                row = row_header + row
-        else:
-            row = None
-
-        return row
-
-    @staticmethod
-    def __get_row_meta_header(headers: List[Tuple[str, str]], timestamp: Tuple[int, int]) -> List[str]:
-        ts = time.ctime(timestamp[1] / 1000)
-
-        user = ''
-        producer = ''
-        host = ''
-
-        if headers is not None:
-            lookup = dict(headers)
-            bytez = lookup.get('user', b'')
-            user = bytez.decode()
-            bytez = lookup.get('producer', b'')
-            producer = bytez.decode()
-            bytez = lookup.get('host', b'')
-            host = bytez.decode()
-
-        return [ts, user, host, producer]
-
     # pylint: disable=unused-argument
     def __signal_handler(self, sig, frame):
         print('Stopping from Ctrl+C!')
         self.stop()
 
 
+class _CacheListener(EventSourceListener):
+    """
+        Internal listener implementation for the JAWSConsumer await highwater feature.
+    """
+
+    def __init__(self):
+        self._cache = {}
+
+    def on_batch(self, msgs: List[Message], highwater_reached: bool) -> None:
+        pass
+
+    def on_highwater(self, cache: Dict[Any, Message]) -> None:
+        self._cache = cache
+
+    def get_cache(self):
+        """
+            Get the cache.  Assumes caller waited on the EventSourceTable.awaitHighwater() first.
+
+            :return: The cached messages Dict
+        """
+        return self._cache
+
+
 class JAWSProducer:
     """
         This class produces messages to JAWS.
@@ -336,7 +252,31 @@ class JAWSProducer:
 
         return key, value
 
-    def import_records(self, file: str) -> None:
+    def __import_lines(self, lines):
+        for line in lines:
+            if line:  # url streaming may contain empty keep-alive lines
+                key, value = self.__from_line(line)
+
+                logger.debug("%s=%s", key, value)
+                self._producer.produce(topic=self._topic, headers=self._headers, key=key, value=value,
+                                       on_delivery=self.__on_delivery)
+
+        self._producer.flush()
+
+    def __import_from_url(self, url: str) -> None:
+        """
+            Send a batch of messages stored in a JAWS formatted file at a URL to a Kafka topic.
+
+            :param url: URL path to a file to import
+        """
+        with requests.get(url, stream=True) as r:
+            if r.encoding is None:
+                r.encoding = 'utf-8'
+
+            lines = r.iter_lines(decode_unicode=True)
+            self.__import_lines(lines)
+
+    def __import_from_file(self, file: str) -> None:
         """
             Send a batch of messages stored in a JAWS formatted file to a Kafka topic.
 
@@ -345,15 +285,18 @@ class JAWSProducer:
         logger.debug("Loading file %s", file)
         with open(file, "r", encoding="utf8") as handle:
             lines = handle.readlines()
+            self.__import_lines(lines)
 
-            for line in lines:
-                key, value = self.__from_line(line)
+    def import_records(self, path: str) -> None:
+        """
+            Send a batch of messages stored in a JAWS formatted file/url to a Kafka topic.
 
-                logger.debug("%s=%s", key, value)
-                self._producer.produce(topic=self._topic, headers=self._headers, key=key, value=value,
-                                       on_delivery=self.__on_delivery)
-
-        self._producer.flush()
+            :param path: Path to file/url to import
+        """
+        if path.startswith("http"):
+            self.__import_from_url(path)
+        else:
+            self.__import_from_file(path)
 
     def __get_headers(self) -> List[Tuple[str, str]]:
         return [('user', Process().username()),
@@ -383,7 +326,14 @@ class ActivationConsumer(JAWSConsumer):
         key_serde = StringSerde()
         value_serde = ActivationSerde(schema_registry_client)
 
-        super().__init__('alarm-activations', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'alarm-activations',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
+
+        super().__init__(config)
 
 
 class CategoryConsumer(JAWSConsumer):
@@ -399,13 +349,14 @@ class CategoryConsumer(JAWSConsumer):
         key_serde = StringSerde()
         value_serde = StringSerde()
 
-        super().__init__('alarm-categories', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'alarm-categories',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ['Category']
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        return [msg.key()]
+        super().__init__(config)
 
 
 class ClassConsumer(JAWSConsumer):
@@ -422,30 +373,19 @@ class ClassConsumer(JAWSConsumer):
         key_serde = StringSerde()
         value_serde = ClassSerde(schema_registry_client)
 
-        super().__init__('alarm-classes', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'alarm-classes',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ["Class Name", "Category", "Priority", "Rationale", "Corrective Action",
-                "P.O.C. Username", "Latching", "Filterable", "On Delay", "Off Delay"]
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        value = msg.value()
-
-        return [msg.key(),
-                value.category,
-                value.priority.name if value.priority is not None else None,
-                value.rationale.replace("\n", "\\n ") if value.rationale is not None else None,
-                value.corrective_action.replace("\n", "\\n") if value.corrective_action is not None else None,
-                value.point_of_contact_username,
-                value.latching,
-                value.filterable,
-                value.on_delay_seconds,
-                value.off_delay_seconds]
+        super().__init__(config)
 
 
-class EffectiveActivationConsumer(JAWSConsumer):
+class EffectiveNotificationConsumer(JAWSConsumer):
     """
-        Consumer for JAWS EffectiveActivation messages.
+        Consumer for JAWS EffectiveNotification messages.
     """
     def __init__(self, client_name: str):
         """
@@ -455,19 +395,16 @@ class EffectiveActivationConsumer(JAWSConsumer):
         """
         schema_registry_client = get_registry_client()
         key_serde = StringSerde()
-        value_serde = EffectiveActivationSerde(schema_registry_client)
+        value_serde = EffectiveNotificationSerde(schema_registry_client)
 
-        super().__init__('effective-activations', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'effective-notifications',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ["Alarm Name", "State", "Overrides"]
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        value = msg.value()
-
-        return [msg.key(),
-                value.state.name,
-                value.overrides]
+        super().__init__(config)
 
 
 class EffectiveAlarmConsumer(JAWSConsumer):
@@ -484,19 +421,14 @@ class EffectiveAlarmConsumer(JAWSConsumer):
         key_serde = StringSerde()
         value_serde = EffectiveAlarmSerde(schema_registry_client)
 
-        super().__init__('effective-alarms', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'effective-alarms',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ["Alarm Name", "State", "Overrides", "Instance", "Class"]
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        value = msg.value()
-
-        return [msg.key(),
-                value.activation.state.name,
-                value.activation.overrides,
-                value.registration.instance,
-                value.registration.alarm_class]
+        super().__init__(config)
 
 
 class EffectiveRegistrationConsumer(JAWSConsumer):
@@ -513,17 +445,14 @@ class EffectiveRegistrationConsumer(JAWSConsumer):
         key_serde = StringSerde()
         value_serde = EffectiveRegistrationSerde(schema_registry_client)
 
-        super().__init__('effective-registrations', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'effective-registrations',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ["Alarm Name", "Instance", "Class"]
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        value = msg.value()
-
-        return [msg.key(),
-                value.instance,
-                value.alarm_class]
+        super().__init__(config)
 
 
 class InstanceConsumer(JAWSConsumer):
@@ -540,20 +469,14 @@ class InstanceConsumer(JAWSConsumer):
         key_serde = StringSerde()
         value_serde = InstanceSerde(schema_registry_client, UnionEncoding.DICT_WITH_TYPE)
 
-        super().__init__('alarm-instances', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'alarm-instances',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ["Alarm Name", "Class", "Producer", "Location", "Masked By", "Screen Command"]
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        value = msg.value()
-
-        return [msg.key(),
-                value.alarm_class,
-                value.producer,
-                value.location,
-                value.masked_by,
-                value.screen_command]
+        super().__init__(config)
 
 
 class LocationConsumer(JAWSConsumer):
@@ -570,16 +493,14 @@ class LocationConsumer(JAWSConsumer):
         key_serde = StringSerde()
         value_serde = LocationSerde(schema_registry_client)
 
-        super().__init__('alarm-locations', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'alarm-locations',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ["Location Name", "Parent"]
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        value = msg.value()
-
-        return [msg.key(),
-                value.parent]
+        super().__init__(config)
 
 
 class OverrideConsumer(JAWSConsumer):
@@ -596,17 +517,14 @@ class OverrideConsumer(JAWSConsumer):
         key_serde = OverrideKeySerde(schema_registry_client)
         value_serde = OverrideSerde(schema_registry_client)
 
-        super().__init__('alarm-overrides', client_name, key_serde, value_serde)
+        config = {
+            'topic': 'alarm-overrides',
+            'client.name': client_name,
+            'key.serde': key_serde,
+            'value.serde': value_serde
+        }
 
-    def _get_table_headers(self) -> List[str]:
-        return ["Alarm Name", "Override Type", "Value"]
-
-    def _get_table_row(self, msg: Message) -> List[str]:
-        key = msg.key()
-
-        return [key.name,
-                key.type.name,
-                msg.value()]
+        super().__init__(config)
 
 
 class ActivationProducer(JAWSProducer):
@@ -659,9 +577,9 @@ class ClassProducer(JAWSProducer):
         super().__init__('alarm-classes', client_name, key_serde, value_serde)
 
 
-class EffectiveActivationProducer(JAWSProducer):
+class EffectiveNotificationProducer(JAWSProducer):
     """
-        Producer for JAWS EffectiveActivation messages.
+        Producer for JAWS EffectiveNotification messages.
     """
     def __init__(self, client_name: str):
         """
@@ -671,9 +589,9 @@ class EffectiveActivationProducer(JAWSProducer):
         """
         schema_registry_client = get_registry_client()
         key_serde = StringSerde()
-        value_serde = EffectiveActivationSerde(schema_registry_client)
+        value_serde = EffectiveNotificationSerde(schema_registry_client)
 
-        super().__init__('effective-activations', client_name, key_serde, value_serde)
+        super().__init__('effective-notifications', client_name, key_serde, value_serde)
 
 
 class EffectiveAlarmProducer(JAWSProducer):
